OiRA

Help

1. Préparation
2. Impliquer
3. Identification + Estimation
4. Plan d'action
5. Rapport
6. Avancement 0%

# Téléchargez et imprimez le rapport et le plan d’action

Nous vous recommandons de toujours avoir dans votre établissement une copie imprimée et mise à jour de votre évaluation de risques!

Rapport

- Format: Rich Text Format (.rtf)
- Contains: all the information and input provided by you throughout the risk assessment process.

Plan d'action

- Format: Office Open XML Workbook (.xlsx)
- Contains: main elements to effectively manage the risks at your workplace.

Aperçu des risques

- Format: Portable Document Format (.pdf)
- Contains: an overview of the risks identified

Vue d’ensemble des mesures

- Format: Portable Document Format (.pdf)
- Contains: an overview of the measures to be implemented.

Scroll to top
Back

## report-download.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More